@@ -18,8 +18,6 @@ pub use chrono::{DateTime, Utc};
 
 pub use http;
 pub use dropshot;
-pub use schemars;
-pub use serde;
 
 pub mod address;
 pub mod error;
